@@ -43,7 +43,8 @@ namespace snapper
 
     enum class Id
     {
-	NONE, NAME, TYPE, NUMBER, PRE_NUMBER, POST_NUMBER, DESCRIPTION, USERDATA
+	NONE, NAME, TYPE, NUMBER, PRE_NUMBER, POST_NUMBER, DESCRIPTION, USERDATA, SSH_HOST, SSH_USER, SSH_PORT,
+	SSH_IDENTITY
     };
 
 
