@@ -9,7 +9,10 @@
 #define ZYPPER_UTILS_TEXT_H_
 
 #include <string>
-#include <iosfwd>
+
+
+namespace snapper
+{
 
 const char* _(const char* msgid) __attribute__ ((format_arg(1)));
 
@@ -29,4 +32,6 @@ std::string mbs_substr_by_width(
     std::string::size_type pos,
     std::string::size_type n = std::string::npos);
 
-#endif /* ZYPPER_UTILS_TEXT_H_ */
+}
+
+#endif
